==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/FileDialogs/TwoPanelFileDialog/translations/two_panel_file_dialog_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>TwoPanelFileDialog</name>
    <message>
        <location filename="../twopanelfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>Ajouter des fichiers</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="70"/>
        <source>File name:</source>
        <translation>Nom du fichier :</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="80"/>
        <source>Files of type:</source>
        <translation>Fichiers de type :</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="117"/>
        <source>Play</source>
        <translation>Jouer</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="130"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="143"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>TwoPanelFileDialogFactory</name>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="67"/>
        <location filename="../twopanelfiledialog.cpp" line="77"/>
        <source>Two-panel File Dialog</source>
        <translation>Fenêtre des fichiers splitée</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="76"/>
        <source>About Two-panel File Dialog</source>
        <translation>A propos de la fenêtre des fichiers splitée</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="78"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="79"/>
        <source>Based on code from the Qt library</source>
        <translation>Basé sur du code provenant de la librairie Qt</translation>
    </message>
</context>
<context>
    <name>TwoPanelFileDialogImpl</name>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="322"/>
        <location filename="../twopanelfiledialogimpl.cpp" line="338"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="340"/>
        <source>Directories</source>
        <translation>Répertoires</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="352"/>
        <source>Save</source>
        <translation>Sauver</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="459"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 existe déjà.
Voulez-vous le remplacer ?</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/FileDialogs/TwoPanelFileDialog/translations/two_panel_file_dialog_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>TwoPanelFileDialog</name>
    <message>
        <location filename="../twopanelfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>Ajouter des fichiers</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="70"/>
        <source>File name:</source>
        <translation>Nom du fichier&#xa0;:</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="80"/>
        <source>Files of type:</source>
        <translation>Fichiers de type&#xa0;:</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="117"/>
        <source>Play</source>
        <translation>Jouer</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="130"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="143"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>TwoPanelFileDialogFactory</name>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="67"/>
        <location filename="../twopanelfiledialog.cpp" line="77"/>
        <source>Two-panel File Dialog</source>
        <translation>Fenêtre des fichiers splitée</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="76"/>
        <source>About Two-panel File Dialog</source>
        <translation>A propos de la fenêtre des fichiers splitée</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="78"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="79"/>
        <source>Based on code from the Qt library</source>
        <translation>Basé sur du code provenant de la librairie Qt</translation>
    </message>
</context>
<context>
    <name>TwoPanelFileDialogImpl</name>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="322"/>
        <location filename="../twopanelfiledialogimpl.cpp" line="338"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="340"/>
        <source>Directories</source>
        <translation>Répertoires</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="352"/>
        <source>Save</source>
        <translation>Sauver</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="458"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 existe déjà.
Voulez-vous le remplacer&#xa0;?</translation>
    </message>
</context>
</TS>
